@@ -7,17 +7,14 @@
 #include "devices.h"
 #include "devices_p.h"
 
-
 #include <solid/device.h>
-#include <solid/deviceinterface.h>
 #include <solid/devicenotifier.h>
 #include <solid/genericinterface.h>
 
 namespace Solid
 {
-
 // Maps queries to the handler objects
-QHash<QString, QWeakPointer<DevicesQueryPrivate> > DevicesQueryPrivate::handlers;
+QHash<QString, QWeakPointer<DevicesQueryPrivate>> DevicesQueryPrivate::handlers;
 
 QSharedPointer<DevicesQueryPrivate> DevicesQueryPrivate::forQuery(const QString &query)
 {
@@ -42,10 +39,8 @@ DevicesQueryPrivate::DevicesQueryPrivate(const QString &query)
     , predicate(Solid::Predicate::fromString(query))
     , notifier(Solid::DeviceNotifier::instance())
 {
-    connect(notifier, &Solid::DeviceNotifier::deviceAdded,
-            this,     &DevicesQueryPrivate::addDevice);
-    connect(notifier, &Solid::DeviceNotifier::deviceRemoved,
-            this,     &DevicesQueryPrivate::removeDevice);
+    connect(notifier, &Solid::DeviceNotifier::deviceAdded, this, &DevicesQueryPrivate::addDevice);
+    connect(notifier, &Solid::DeviceNotifier::deviceRemoved, this, &DevicesQueryPrivate::removeDevice);
 
     if (!query.isEmpty() && !predicate.isValid()) {
         return;
@@ -66,7 +61,7 @@ void DevicesQueryPrivate::addDevice(const QString &udi)
 {
     if (predicate.isValid() && predicate.matches(Solid::Device(udi))) {
         matchingDevices << udi;
-        emit deviceAdded(udi);
+        Q_EMIT deviceAdded(udi);
     }
 }
 
@@ -74,7 +69,7 @@ void DevicesQueryPrivate::removeDevice(const QString &udi)
 {
     if (predicate.isValid() && matchingDevices.contains(udi)) {
         matchingDevices.removeAll(udi);
-        emit deviceRemoved(udi);
+        Q_EMIT deviceRemoved(udi);
     }
 }
 
@@ -91,19 +86,16 @@ void Devices::initialize() const
 
     m_backend = DevicesQueryPrivate::forQuery(m_query);
 
-    connect(m_backend.data(), &DevicesQueryPrivate::deviceAdded,
-            this, &Devices::addDevice);
-    connect(m_backend.data(), &DevicesQueryPrivate::deviceAdded,
-            this, &Devices::addDevice);
-    connect(m_backend.data(), &DevicesQueryPrivate::deviceRemoved,
-            this, &Devices::removeDevice);
+    connect(m_backend.data(), &DevicesQueryPrivate::deviceAdded, this, &Devices::addDevice);
+    connect(m_backend.data(), &DevicesQueryPrivate::deviceAdded, this, &Devices::addDevice);
+    connect(m_backend.data(), &DevicesQueryPrivate::deviceRemoved, this, &Devices::removeDevice);
 
     const int matchesCount = m_backend->devices().count();
 
     if (matchesCount != 0) {
-        emit emptyChanged(false);
-        emit countChanged(matchesCount);
-        emit devicesChanged(m_backend->devices());
+        Q_EMIT emptyChanged(false);
+        Q_EMIT countChanged(matchesCount);
+        Q_EMIT devicesChanged(m_backend->devices());
     }
 }
 
@@ -116,9 +108,9 @@ void Devices::reset()
     m_backend->disconnect(this);
     m_backend.reset();
 
-    emit emptyChanged(true);
-    emit countChanged(0);
-    emit devicesChanged(QStringList());
+    Q_EMIT emptyChanged(true);
+    Q_EMIT countChanged(0);
+    Q_EMIT devicesChanged(QStringList());
 }
 
 void Devices::addDevice(const QString &udi)
@@ -130,12 +122,12 @@ void Devices::addDevice(const QString &udi)
     const int count = m_backend->devices().count();
 
     if (count == 1) {
-        emit emptyChanged(false);
+        Q_EMIT emptyChanged(false);
     }
 
-    emit countChanged(count);
-    emit devicesChanged(m_backend->devices());
-    emit deviceAdded(udi);
+    Q_EMIT countChanged(count);
+    Q_EMIT devicesChanged(m_backend->devices());
+    Q_EMIT deviceAdded(udi);
 }
 
 void Devices::removeDevice(const QString &udi)
@@ -147,12 +139,12 @@ void Devices::removeDevice(const QString &udi)
     const int count = m_backend->devices().count();
 
     if (count == 0) {
-        emit emptyChanged(true);
+        Q_EMIT emptyChanged(true);
     }
 
-    emit countChanged(count);
-    emit devicesChanged(m_backend->devices());
-    emit deviceRemoved(udi);
+    Q_EMIT countChanged(count);
+    Q_EMIT devicesChanged(m_backend->devices());
+    Q_EMIT deviceRemoved(udi);
 }
 
 Devices::Devices(QObject *parent)
@@ -198,7 +190,7 @@ void Devices::setQuery(const QString &query)
     reset();
     initialize();
 
-    emit queryChanged(query);
+    Q_EMIT queryChanged(query);
 }
 
 QObject *Devices::device(const QString &udi, const QString &_type)
@@ -209,3 +201,5 @@ QObject *Devices::device(const QString &udi, const QString &_type)
 }
 } // namespace Solid
 
+#include "moc_devices.cpp"
+#include "moc_devices_p.cpp"
