@@ -6,7 +6,6 @@
 
 #include "iokitstorage.h"
 
-
 #include <CoreFoundation/CoreFoundation.h>
 #include <DiskArbitration/DiskArbitration.h>
 
@@ -55,8 +54,8 @@ Solid::StorageDrive::DriveType IOKitStorage::driveType() const
     const QString udi = m_device->udi();
     const QString type = m_device->property(QLatin1String("className")).toString();
 
-    if (type == QStringLiteral("IOCDMedia")
-        || type == QStringLiteral("IOBDMedia")
+    if (type == QStringLiteral("IOCDMedia") //
+        || type == QStringLiteral("IOBDMedia") //
         || type == QStringLiteral("IODVDMedia")) {
         return Solid::StorageDrive::CdromDrive;
     }
@@ -79,8 +78,9 @@ bool IOKitStorage::isRemovable() const
 bool IOKitStorage::isHotpluggable() const
 {
     const Solid::StorageDrive::DriveType type = driveType();
-    return bus() == Solid::StorageDrive::Usb
-        || type == Solid::StorageDrive::CdromDrive || type == Solid::StorageDrive::SdMmc;
+    return bus() == Solid::StorageDrive::Usb //
+        || type == Solid::StorageDrive::CdromDrive //
+        || type == Solid::StorageDrive::SdMmc;
 }
 
 qulonglong IOKitStorage::size() const
@@ -102,3 +102,5 @@ QString IOKitStorage::description() const
 {
     return daDict->stringForKey(kDADiskDescriptionMediaNameKey);
 }
+
+#include "moc_iokitstorage.cpp"
