@@ -7,14 +7,18 @@
 #include "udevqtclient.h"
 #include "udevqt_p.h"
 
+#include "devices_debug.h"
+
 #include <QSocketNotifier>
 #include <qplatformdefs.h>
 
 namespace UdevQt
 {
-
 ClientPrivate::ClientPrivate(Client *q_)
-    : udev(nullptr), monitor(nullptr), q(q_), monitorNotifier(nullptr)
+    : udev(nullptr)
+    , monitor(nullptr)
+    , q(q_)
+    , monitorNotifier(nullptr)
 {
 }
 
@@ -92,34 +96,35 @@ void ClientPrivate::_uq_monitorReadyRead(int fd)
 
     QByteArray action(udev_device_get_action(dev));
     if (action == "add") {
-        emit q->deviceAdded(device);
+        Q_EMIT q->deviceAdded(device);
     } else if (action == "remove") {
-        emit q->deviceRemoved(device);
+        Q_EMIT q->deviceRemoved(device);
     } else if (action == "change") {
-        emit q->deviceChanged(device);
+        Q_EMIT q->deviceChanged(device);
     } else if (action == "online") {
-        emit q->deviceOnlined(device);
-    } else  if (action == "offline") {
-        emit q->deviceOfflined(device);
-    } else  if (action == "bind") {
-        emit q->deviceBound(device);
-    } else  if (action == "unbind") {
-        emit q->deviceUnbound(device);
+        Q_EMIT q->deviceOnlined(device);
+    } else if (action == "offline") {
+        Q_EMIT q->deviceOfflined(device);
+    } else if (action == "bind") {
+        Q_EMIT q->deviceBound(device);
+    } else if (action == "unbind") {
+        Q_EMIT q->deviceUnbound(device);
     } else {
-        qWarning("UdevQt: unhandled device action \"%s\"", action.constData());
+        qCDebug(Solid::Frontend::DeviceManager::DEVICEMANAGER) << "UdevQt: unhandled action:" << action.constData() << "for device:" << device.sysfsPath();
     }
 }
 
 DeviceList ClientPrivate::deviceListFromEnumerate(struct udev_enumerate *en)
 {
     DeviceList ret;
-    struct udev_list_entry *list, *entry;
+    struct udev_list_entry *list;
+    struct udev_list_entry *entry;
 
     udev_enumerate_scan_devices(en);
     list = udev_enumerate_get_list_entry(en);
-    udev_list_entry_foreach(entry, list) {
-        struct udev_device *ud = udev_device_new_from_syspath(udev_enumerate_get_udev(en),
-                                 udev_list_entry_get_name(entry));
+    udev_list_entry_foreach(entry, list)
+    {
+        struct udev_device *ud = udev_device_new_from_syspath(udev_enumerate_get_udev(en), udev_list_entry_get_name(entry));
 
         if (!ud) {
             continue;
@@ -260,9 +265,9 @@ Device Client::deviceBySysfsPath(const QString &sysfsPath)
 
 Device Client::deviceBySubsystemAndName(const QString &subsystem, const QString &name)
 {
-    struct udev_device *ud = udev_device_new_from_subsystem_sysname(d->udev,
-                             subsystem.toLatin1().constData(),
-                             name.toLatin1().constData());
+    struct udev_device *ud = udev_device_new_from_subsystem_sysname(d->udev, //
+                                                                    subsystem.toLatin1().constData(),
+                                                                    name.toLatin1().constData());
 
     if (!ud) {
         return Device();
