@@ -7,9 +7,9 @@
 #ifndef SOLID_BACKENDS_UDEV_GENERICINTERFACE_H
 #define SOLID_BACKENDS_UDEV_GENERICINTERFACE_H
 
+#include "udevdeviceinterface.h"
 #include <solid/devices/ifaces/genericinterface.h>
 #include <solid/genericinterface.h>
-#include "udevdeviceinterface.h"
 
 namespace Solid
 {
@@ -26,7 +26,7 @@ class GenericInterface : public DeviceInterface, virtual public Solid::Ifaces::G
 
 public:
     GenericInterface(UDevDevice *device);
-    virtual ~GenericInterface();
+    ~GenericInterface() override;
 
     QVariant property(const QString &key) const override;
     QMap<QString, QVariant> allProperties() const override;
