@@ -1,22 +1,8 @@
 /*
-    Copyright 2010 Michael Zanetti <mzanetti@kde.org>
-    Copyright 2010-2012 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2010 Michael Zanetti <mzanetti@kde.org>
+    SPDX-FileCopyrightText: 2010-2012 Lukáš Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef UDISKSDEVICE_H
@@ -37,15 +23,14 @@ namespace Backends
 {
 namespace UDisks2
 {
-
 class DeviceBackend;
 
-class Device: public Solid::Ifaces::Device
+class Device : public Solid::Ifaces::Device
 {
     Q_OBJECT
 public:
     Device(const QString &udi);
-    virtual ~Device();
+    ~Device() override;
 
     QObject *createDeviceInterface(const Solid::DeviceInterface::Type &type) override;
     bool queryDeviceInterface(const Solid::DeviceInterface::Type &type) const override;
