@@ -83,8 +83,8 @@ static QString baseMountPoint(const QByteArray &dev)
     // UDisks "MountPoints" property contains multiple paths, this happens with
     // devices with bind mounts; try finding the "base" mount point
     if (struct libmnt_table *table = mnt_new_table()) {
-        // This parses "/proc/self/mountinfo" by default
-        if (mnt_table_parse_mtab(table, nullptr) == 0) {
+        // This parses "/etc/mtab" if present or "/proc/self/mountinfo" by default
+        if (mnt_table_parse_mtab(table, "/proc/self/mountinfo") == 0) {
             // BACKWARD because the fs's we're interested in, /dev/sdXY, are typically at the end
             struct libmnt_iter *itr = mnt_new_iter(MNT_ITER_BACKWARD);
             struct libmnt_fs *fs;
@@ -92,9 +92,9 @@ static QString baseMountPoint(const QByteArray &dev)
             const QByteArray devicePath = dev.endsWith('\x00') ? dev.chopped(1) : dev;
 
             while (mnt_table_next_fs(table, itr, &fs) == 0) {
-                if (mnt_fs_get_srcpath(fs) == devicePath
-                    // Base mount point will have "/" as root fs
-                    && (strcmp(mnt_fs_get_root(fs), "/") == 0)) {
+                if (mnt_fs_get_srcpath(fs) == devicePath //
+                    && (qstrcmp(mnt_fs_get_root(fs), "/") == 0) // Base mount point will have "/" as root fs
+                ) {
                     mountPoint = QFile::decodeName(mnt_fs_get_target(fs));
                     break;
                 }
@@ -105,6 +105,8 @@ static QString baseMountPoint(const QByteArray &dev)
 
         mnt_free_table(table);
     }
+#else
+    Q_UNUSED(dev);
 #endif
 
     return mountPoint;
@@ -131,7 +133,12 @@ QString StorageAccess::filePath() const
         return {};
     }
 
-    const QString potentialMountPoint = QFile::decodeName(mntPoints.first());
+    QByteArray first = mntPoints.first();
+    if (first.endsWith('\x00')) {
+        first.chop(1);
+    }
+    const QString potentialMountPoint = QFile::decodeName(first);
+
     if (mntPoints.size() == 1) {
         return potentialMountPoint;
     }
@@ -148,6 +155,11 @@ bool StorageAccess::isIgnored() const
         return true;
     }
 
+    const QStringList mountOptions = m_device->prop("UserspaceMountOptions").toStringList();
+    if (mountOptions.contains(QLatin1String("x-gdu.hide"))) {
+        return true;
+    }
+
     const QString path = filePath();
 
     const bool inUserPath = (path.startsWith(QLatin1String("/media/")) //
@@ -215,7 +227,7 @@ void StorageAccess::slotDBusReply(const QDBusMessage & /*reply*/)
         if (isLuksDevice() && !ctPath.isEmpty() && ctPath != "/") { // unlocked device, lock it
             callCryptoTeardown();
         } else if (!ctPath.isEmpty() && ctPath != "/") {
-            callCryptoTeardown(true); // Lock crypted parent
+            callCryptoTeardown(true); // Lock encrypted parent
         } else {
             // try to "eject" (aka safely remove) from the (parent) drive, e.g. SD card from a reader
             QString drivePath = m_device->drivePath();
@@ -348,9 +360,8 @@ QString StorageAccess::generateReturnObjectPath()
 
 QString StorageAccess::clearTextPath() const
 {
-    const QString prefix = "/org/freedesktop/UDisks2/block_devices";
     QDBusMessage call = QDBusMessage::createMethodCall(UD2_DBUS_SERVICE, //
-                                                       prefix,
+                                                       UD2_DBUS_PATH_BLOCKDEVICES,
                                                        DBUS_INTERFACE_INTROSPECT,
                                                        "Introspect");
     QDBusPendingReply<QString> reply = QDBusConnection::systemBus().asyncCall(call);
@@ -363,7 +374,7 @@ QString StorageAccess::clearTextPath() const
         for (int i = 0; i < nodeList.count(); i++) {
             QDomElement nodeElem = nodeList.item(i).toElement();
             if (!nodeElem.isNull() && nodeElem.hasAttribute("name")) {
-                const QString udi = prefix + "/" + nodeElem.attribute("name");
+                const QString udi = UD2_DBUS_PATH_BLOCKDEVICES + QLatin1Char('/') + nodeElem.attribute("name");
                 Device holderDevice(udi);
 
                 if (m_device->udi() == holderDevice.prop("CryptoBackingDevice").value<QDBusObjectPath>().path()) {
@@ -441,3 +452,5 @@ bool StorageAccess::callCryptoTeardown(bool actOnParent)
 
     return c.callWithCallback(msg, this, SLOT(slotDBusReply(QDBusMessage)), SLOT(slotDBusError(QDBusError)));
 }
+
+#include "moc_udisksstorageaccess.cpp"
