@@ -7,39 +7,39 @@
 
 #include "upowerdevice.h"
 #include "upower.h"
+#include "upowerbattery.h"
 #include "upowerdeviceinterface.h"
 #include "upowergenericinterface.h"
-#include "upowerbattery.h"
 
-#include <solid/genericinterface.h>
 #include <solid/device.h>
+#include <solid/genericinterface.h>
 
-#include <QStringList>
 #include <QDBusReply>
+#include <QStringList>
 
 using namespace Solid::Backends::UPower;
 
 UPowerDevice::UPowerDevice(const QString &udi)
     : Solid::Ifaces::Device()
-    , m_device(UP_DBUS_SERVICE,
-               udi,
-               UP_DBUS_INTERFACE_DEVICE,
-               QDBusConnection::systemBus())
+    , m_device(UP_DBUS_SERVICE, udi, UP_DBUS_INTERFACE_DEVICE, QDBusConnection::systemBus())
     , m_udi(udi)
 {
     if (m_device.isValid()) {
-        if (m_device.metaObject()->indexOfSignal("Changed()") != -1) {
-            connect(&m_device, SIGNAL(Changed()), this, SLOT(slotChanged()));
-        } else {
-            // for UPower >= 0.99.0, missing Changed() signal
-            QDBusConnection::systemBus().connect(UP_DBUS_SERVICE, m_udi, "org.freedesktop.DBus.Properties", "PropertiesChanged", this,
-                                                 SLOT(onPropertiesChanged(QString,QVariantMap,QStringList)));
-        }
+        QDBusConnection::systemBus().connect(UP_DBUS_SERVICE,
+                                             m_udi,
+                                             "org.freedesktop.DBus.Properties",
+                                             "PropertiesChanged",
+                                             this,
+                                             SLOT(onPropertiesChanged(QString, QVariantMap, QStringList)));
 
         // TODO port this to Solid::Power, we can't link against kdelibs4support for this signal
         // older upower versions not affected
-        QDBusConnection::systemBus().connect("org.freedesktop.login1", "/org/freedesktop/login1", "org.freedesktop.login1.Manager", "PrepareForSleep",
-                                             this, SLOT(login1Resuming(bool)));
+        QDBusConnection::systemBus().connect("org.freedesktop.login1",
+                                             "/org/freedesktop/login1",
+                                             "org.freedesktop.login1.Manager",
+                                             "PrepareForSleep",
+                                             this,
+                                             SLOT(login1Resuming(bool)));
     }
 }
 
@@ -69,7 +69,7 @@ QObject *UPowerDevice::createDeviceInterface(const Solid::DeviceInterface::Type
 
 bool UPowerDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type) const
 {
-    const uint uptype = prop("Type").toUInt();
+    const UpDeviceKind uptype = static_cast<UpDeviceKind>(prop("Type").toUInt());
     switch (type) {
     case Solid::DeviceInterface::GenericInterface:
         return true;
@@ -81,7 +81,13 @@ bool UPowerDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type
         case UP_DEVICE_KIND_KEYBOARD:
         case UP_DEVICE_KIND_PDA:
         case UP_DEVICE_KIND_PHONE:
+        case UP_DEVICE_KIND_TABLET:
         case UP_DEVICE_KIND_GAMING_INPUT:
+        case UP_DEVICE_KIND_SPEAKERS:
+        case UP_DEVICE_KIND_HEADSET:
+        case UP_DEVICE_KIND_HEADPHONES:
+        case UP_DEVICE_KIND_BLUETOOTH_GENERIC:
+        case UP_DEVICE_KIND_TOUCHPAD:
             return true;
         case UP_DEVICE_KIND_UNKNOWN:
             // There is currently no "Bluetooth battery" type, so check if it comes from Bluez
@@ -92,11 +98,11 @@ bool UPowerDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type
         case UP_DEVICE_KIND_LINE_POWER:
         case UP_DEVICE_KIND_MONITOR:
         case UP_DEVICE_KIND_MEDIA_PLAYER:
-        case UP_DEVICE_KIND_TABLET:
         case UP_DEVICE_KIND_COMPUTER:
         case UP_DEVICE_KIND_LAST:
             return false;
         }
+        Q_FALLTHROUGH();
     default:
         return false;
     }
@@ -122,23 +128,26 @@ QString UPowerDevice::description() const
 
 QString UPowerDevice::batteryTechnology() const
 {
-    const uint tech = prop("Technology").toUInt();
+    const UpDeviceTechnology tech = static_cast<UpDeviceTechnology>(prop("Technology").toUInt());
     switch (tech) {
-    case 1:
+    case UP_DEVICE_TECHNOLOGY_UNKNOWN:
+        return tr("Unknown", "battery technology");
+    case UP_DEVICE_TECHNOLOGY_LITHIUM_ION:
         return tr("Lithium Ion", "battery technology");
-    case 2:
+    case UP_DEVICE_TECHNOLOGY_LITHIUM_POLYMER:
         return tr("Lithium Polymer", "battery technology");
-    case 3:
+    case UP_DEVICE_TECHNOLOGY_LITHIUM_IRON_PHOSPHATE:
         return tr("Lithium Iron Phosphate", "battery technology");
-    case 4:
+    case UP_DEVICE_TECHNOLOGY_LEAD_ACID:
         return tr("Lead Acid", "battery technology");
-    case 5:
+    case UP_DEVICE_TECHNOLOGY_NICKEL_CADMIUM:
         return tr("Nickel Cadmium", "battery technology");
-    case 6:
+    case UP_DEVICE_TECHNOLOGY_NICKEL_METAL_HYDRIDE:
         return tr("Nickel Metal Hydride", "battery technology");
-    default:
+    case UP_DEVICE_TECHNOLOGY_LAST:
         return tr("Unknown", "battery technology");
     }
+    return tr("Unknown", "battery technology");
 }
 
 QString UPowerDevice::icon() const
@@ -178,10 +187,12 @@ QString UPowerDevice::parentUdi() const
 
 void UPowerDevice::checkCache(const QString &key) const
 {
-    if (m_cache.isEmpty()) { // recreate the cache
-        allProperties();
+    if (m_cache.contains(key) || m_negativeCache.contains(key)) {
+        return;
     }
 
+    loadCache();
+
     if (m_cache.contains(key)) {
         return;
     }
@@ -191,7 +202,7 @@ void UPowerDevice::checkCache(const QString &key) const
     if (reply.isValid()) {
         m_cache[key] = reply;
     } else {
-        m_cache[key] = QVariant();
+        m_negativeCache.append(key);
     }
 }
 
@@ -207,46 +218,64 @@ bool UPowerDevice::propertyExists(const QString &key) const
     return m_cache.contains(key);
 }
 
-QMap<QString, QVariant> UPowerDevice::allProperties() const
+void UPowerDevice::loadCache() const
 {
-    QDBusMessage call = QDBusMessage::createMethodCall(m_device.service(), m_device.path(),
-                        "org.freedesktop.DBus.Properties", "GetAll");
+    QDBusMessage call = QDBusMessage::createMethodCall(m_device.service(), m_device.path(), "org.freedesktop.DBus.Properties", "GetAll");
     call << m_device.interface();
-    QDBusPendingReply< QVariantMap > reply = QDBusConnection::systemBus().asyncCall(call);
+    QDBusPendingReply<QVariantMap> reply = QDBusConnection::systemBus().asyncCall(call);
     reply.waitForFinished();
 
     if (reply.isValid()) {
         m_cache = reply.value();
+        m_cacheComplete = true;
     } else {
         m_cache.clear();
     }
+}
+
+QMap<QString, QVariant> UPowerDevice::allProperties() const
+{
+    if (!m_cacheComplete) {
+        loadCache();
+    }
 
     return m_cache;
 }
 
 void UPowerDevice::onPropertiesChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps)
 {
-    Q_UNUSED(changedProps);
-    Q_UNUSED(invalidatedProps);
+    if (ifaceName != UP_DBUS_INTERFACE_DEVICE)
+	return;
 
-    if (ifaceName == UP_DBUS_INTERFACE_DEVICE) {
-        slotChanged(); // TODO maybe process the properties separately?
+    QMap<QString, int> changeMap;
+    for (auto it = changedProps.begin(); it != changedProps.end(); ++it) {
+        m_cache[it.key()] = it.value();
+        changeMap.insert(it.key(), Solid::GenericInterface::PropertyModified);
     }
-}
-
-void UPowerDevice::slotChanged()
-{
-    // given we cannot know which property/ies changed, clear the cache
-    m_cache.clear();
-    emit changed();
+    for (const auto &propName : invalidatedProps) {
+        m_cache.remove(propName);
+        changeMap.insert(propName, Solid::GenericInterface::PropertyModified);
+        m_cacheComplete = false;
+    }
+    Q_EMIT propertyChanged(changeMap);
 }
 
 void UPowerDevice::login1Resuming(bool active)
 {
-    if (!active) {
-        QDBusReply<void> refreshCall = m_device.asyncCall("Refresh");
-        if (refreshCall.isValid()) {
-            slotChanged();
-        }
+    // Nothing to do when going into sleep
+    if (active)
+        return;
+
+    QMap<QString, int> changeMap;
+    for (auto it = m_cache.begin(); it != m_cache.end(); ++it) {
+        if (it.value().isValid()) {
+            changeMap.insert(it.key(), Solid::GenericInterface::PropertyModified);
+	}
     }
+    m_cache.clear();
+    m_negativeCache.clear();
+    m_cacheComplete = false;
+    Q_EMIT propertyChanged(changeMap);
 }
+
+#include "moc_upowerdevice.cpp"
